package com.jiuqi.office.excel;

import com.jiuqi.util.StringUtils;
import java.io.InputStream;
import java.io.ByteArrayInputStream;
import java.util.Date;
import com.jiuqi.util.zip.ZipEntry;
import java.io.ByteArrayOutputStream;
import com.jiuqi.util.zip.ZipOutputStream;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import com.jiuqi.grid.GridData;
import java.io.IOException;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import java.io.OutputStream;
import java.util.HashSet;
import java.util.Map;
import java.util.HashMap;
import java.util.Set;

public class BatchExportor
{
    private boolean autoAdjust;
    private boolean addTitle;
    private boolean toSingleFile;
    private GridIterator iterator;
    private Set filenames;
    private HashMap cellStyleHashMap;
    private int transparentColor;
    private boolean doNotCheckNumberIsNull;
    private Map HSSFFontMap;
    
    public BatchExportor(final GridIterator iterator) {
        this.iterator = iterator;
        this.filenames = new HashSet();
        this.cellStyleHashMap = new HashMap();
        this.transparentColor = -16777201;
        this.HSSFFontMap = new HashMap();
    }
    
    public void setAutoAdjust(final boolean autoAdjust) {
        this.autoAdjust = autoAdjust;
    }
    
    public void setAddTitle(final boolean addTitle) {
        this.addTitle = addTitle;
    }
    
    public void setToSingleFile(final boolean toSingleFile) {
        this.toSingleFile = toSingleFile;
    }
    
    public void setTransparentColor(final int transparentColor) {
        this.transparentColor = transparentColor;
    }
    
    public boolean isDoNotCheckNumberIsNull() {
        return this.doNotCheckNumberIsNull;
    }
    
    public void setDoNotCheckNumberIsNull(final boolean doNotCheckNumberIsNull) {
        this.doNotCheckNumberIsNull = doNotCheckNumberIsNull;
    }
    
    public boolean isAutoAdjust() {
        return this.autoAdjust;
    }
    
    public boolean isAddTitle() {
        return this.addTitle;
    }
    
    public boolean isToSingleFile() {
        return this.toSingleFile;
    }
    
    public void Export(final OutputStream outStream) throws Exception {
        if (this.toSingleFile) {
            this.exportToSingle(outStream);
        }
        else {
            this.exportToBatch(outStream);
        }
    }
    
    private void exportToSingle(final OutputStream outStream) throws ExcelException {
        this.filenames.clear();
        GridData reportData = null;
        final HSSFWorkbook wb = new HSSFWorkbook();
        while (this.iterator.next()) {
            reportData = this.iterator.getGridData();
            final String rptTitle = this.validateFileName(this.iterator.getTitle());
            final HSSFSheet sheet = wb.createSheet(rptTitle);
            final WorksheetWriter sheetWriter = new WorksheetWriter(wb, sheet, reportData, this.cellStyleHashMap);
            sheetWriter.setHSSFFontMap(this.HSSFFontMap);
            sheetWriter.setAddTitle(this.addTitle);
            if (this.addTitle) {
                sheetWriter.setTitle(this.iterator.getTitle());
            }
            else {
                sheetWriter.setTitle("");
            }
            sheetWriter.setAutoAdjust(this.autoAdjust);
            sheetWriter.setDoNotCheckNumberIsNull(this.doNotCheckNumberIsNull);
            sheetWriter.setTransparentColor(this.transparentColor);
            sheetWriter.writeWorkSheet();
        }
        try {
            wb.write(outStream);
        }
        catch (final IOException e) {
            throw new ExcelException(e);
        }
    }
    
    private void exportToBatch(final OutputStream outStream) throws ExcelException {
        this.filenames.clear();
        final ZipOutputStream zipOutStream = new ZipOutputStream(outStream);
        ZipEntry zipEntry = null;
        final byte[] buf = new byte[1024];
        int readLen = 0;
        while (this.iterator.next()) {
            final SimpleExportor excelExportor = new SimpleExportor(this.iterator.getTitle(), this.iterator.getGridData());
            excelExportor.setHSSFFontMap((HashMap)this.HSSFFontMap);
            excelExportor.setAddTitle(this.addTitle);
            excelExportor.setAutoAdjust(this.autoAdjust);
            excelExportor.setDoNotCheckNumberIsNull(this.doNotCheckNumberIsNull);
            final ByteArrayOutputStream outBuffer = new ByteArrayOutputStream();
            excelExportor.export(outBuffer);
            zipEntry = new ZipEntry(String.valueOf(this.validateFileName(this.iterator.getTitle())) + ".xls");
            zipEntry.setSize((long)outBuffer.size());
            final Date now = new Date();
            zipEntry.setTime(now.getTime());
            try {
                zipOutStream.putNextEntry(zipEntry);
                final InputStream is = new ByteArrayInputStream(outBuffer.toByteArray());
                while ((readLen = is.read(buf, 0, 1024)) != -1) {
                    zipOutStream.write(buf, 0, readLen);
                }
            }
            catch (final IOException e) {
                throw new ExcelException(e);
            }
        }
        try {
            zipOutStream.close();
        }
        catch (final IOException e2) {
            throw new ExcelException(e2);
        }
    }
    
    private String validateFileName(String filename) {
        if (StringUtils.isEmpty(filename) || filename.length() >= 32) {
            filename = "report";
        }
        String newName = filename;
        for (int index = 0; this.filenames.contains(newName); newName = String.valueOf(filename) + "_" + Integer.toString(index)) {
            ++index;
        }
        this.filenames.add(newName);
        return newName;
    }
}
